pub struct RepoOutcome {
pub repo: RepoId,
pub status: ScanStatus,
}Expand description
Per-repo scan status. A repo we could not read is Errored and the run
continues — but it forces a non-clean exit (8): you cannot assert
“fleet-clean” over a repo you never read.
Fields
repo: RepoIdstatus: ScanStatusTrait Implementations
Sourceimpl Clone for RepoOutcome
impl Clone for RepoOutcome
Sourcefn clone(&self) -> RepoOutcome
fn clone(&self) -> RepoOutcome
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RepoOutcome
impl Debug for RepoOutcome
Sourceimpl<'de> Deserialize<'de> for RepoOutcome
impl<'de> Deserialize<'de> for RepoOutcome
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RepoOutcome
impl PartialEq for RepoOutcome
Sourcefn eq(&self, other: &RepoOutcome) -> bool
fn eq(&self, other: &RepoOutcome) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RepoOutcome
impl Serialize for RepoOutcome
impl StructuralPartialEq for RepoOutcome